==> CGAL-5.2.2-doc_html.tar.xz: doc_html/Polygon_mesh_processing/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2.2 - Polygon Mesh Processing", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#PMPIntroduction", [
        [ "Polygon Mesh", "index.html#PMPDef", null ],
        [ "API", "index.html#PMPAPI", null ],
        [ "Outline", "index.html#PMPOutline", null ]
      ] ],
      [ "Meshing", "index.html#PMPMeshing", [
        [ "API", "index.html#MeshingAPI", [
          [ "Meshing", "index.html#Meshing", null ],
          [ "Remeshing", "index.html#Remeshing", null ],
          [ "Smoothing", "index.html#Smoothing", null ]
        ] ],
        [ "Meshing Examples", "index.html#MeshingExamples", [
          [ "Refine and Fair a Region on a Triangle Mesh", "index.html#MeshingExample_1", null ],
          [ "Triangulate a Polygon Mesh", "index.html#MeshingExample_2", null ],
          [ "Isotropic Remeshing of a Region on a Polygon Mesh", "index.html#RemeshingExample_1", null ]
        ] ]
      ] ],
      [ "Corefinement and Boolean Operations", "index.html#Coref_section", [
        [ "Definitions", "index.html#coref_def_subsec", null ],
        [ "Corefinement", "index.html#coref_coref_subsec", null ],
        [ "Boolean Operations", "index.html#coref_bolop_subsec", null ],
        [ "Kernel and Validity of the Output", "index.html#coref_valid_subsec", null ],
        [ "Clipping", "index.html#coref_clip", null ],
        [ "Examples", "index.html#coref_ex_subsec", [
          [ "Computing the Union of Two Volumes", "index.html#coref_ex_union_subsec", null ],
          [ "Boolean Operation and Local Remeshing", "index.html#coref_ex_refine_subsec", null ],
          [ "Robustness of Consecutive Operations", "index.html#coref_ex_consq_subsec", null ]
        ] ]
      ] ],
      [ "Hole Filling", "index.html#PMPHoleFilling", [
        [ "API", "index.html#HoleFillingAPI", null ],
        [ "Examples", "index.html#HFExamples", [
          [ "Triangulate a Polyline", "index.html#HFExample_1", null ],
          [ "Hole Filling From the Border of the Hole", "index.html#HFExample_2", null ]
        ] ],
        [ "Performance", "index.html#HFPerformance", null ]
      ] ],
      [ "Predicates", "index.html#PMPPredicates", [
        [ "Intersections Detection", "index.html#PMPDoIntersect", [
          [ "Self Intersections", "index.html#PMPSelIntersections", null ],
          [ "Self Intersections Example", "index.html#SIExample", null ]
        ] ],
        [ "Side of Triangle Mesh", "index.html#PMPInsideTest", [
          [ "Inside Test Example", "index.html#InsideExample", null ]
        ] ],
        [ "Shape Predicates", "index.html#PMPShapePredicates", null ],
        [ "Surface Location Functions", "index.html#PMPLocationFunctions", null ]
      ] ],
      [ "Orientation", "index.html#PMPOrientation", [
        [ "Polygon Soups", "index.html#PolygonSoups", null ],
        [ "Polygon Meshes", "index.html#OrientingPolygonMeshes", null ],
        [ "Orientation Examples", "index.html#PolygonSoupExample", null ]
      ] ],
      [ "Combinatorial Repairing", "index.html#PMPRepairing", [
        [ "Polygon Soup Repairing", "index.html#PSRepairing", null ],
        [ "Stitching", "index.html#Stitching", [
          [ "Stitching Example", "index.html#StitchingExample", null ]
        ] ],
        [ "Polygon Mesh Manifoldness", "index.html#PMPManifoldness", [
          [ "Manifoldness Repair Example", "index.html#FixNMVerticeExample", null ]
        ] ],
        [ "Duplicated Vertices in Boundary Cycles", "index.html#PMPDuplicateVertexBoundaryCycle", null ]
      ] ],
      [ "Computing Normals", "index.html#PMPNormalComp", [
        [ "Normals Computation Examples", "index.html#NormalsExample", [
          [ "Normals Computation for a Surface Mesh", "index.html#NormalsExampleSM", null ],
          [ "Normals Computation for a Polyhedron_3", "index.html#NormalsExampleP", null ]
        ] ]
      ] ],
      [ "Slicer", "index.html#PMPSlicer", [
        [ "Slicer Example", "index.html#SlicerExample", null ]
      ] ],
      [ "Connected Components", "index.html#PMPConnectedComponents", [
        [ "Connected Components Example", "index.html#CCExample", null ]
      ] ],
      [ "Approximate Hausdorff Distance", "index.html#PMPDistance", [
        [ "Approximate Hausdorff Distance Example", "index.html#AHDExample", null ],
        [ "Max Distance Between Point Set and Surface Example", "index.html#PoissonDistanceExample", null ]
      ] ],
      [ "Feature Detection", "index.html#PMPDetectFeatures", [
        [ "Feature Detection Example", "index.html#DetectFeaturesExample", null ]
      ] ],
      [ "Implementation History", "index.html#PMPHistory", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"group__hole__filling__grp.html#gaaa1bfaf9a57dea8b6c71168a18f9b6eb"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Polygon_mesh_processing/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.4.1 - Polygon Mesh Processing", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#PMPIntroduction", [
        [ "Polygon Mesh", "index.html#PMPDef", null ],
        [ "API", "index.html#PMPAPI", null ],
        [ "Outline", "index.html#PMPOutline", null ],
        [ "Reading and Writing Polygon Meshes", "index.html#PMPIO", null ]
      ] ],
      [ "Meshing", "index.html#PMPMeshing", [
        [ "API", "index.html#MeshingAPI", [
          [ "Meshing", "index.html#Meshing", null ],
          [ "Remeshing", "index.html#Remeshing", null ],
          [ "Smoothing", "index.html#Smoothing", null ]
        ] ],
        [ "Meshing Examples", "index.html#MeshingExamples", [
          [ "Refine and Fair a Region on a Triangle Mesh", "index.html#MeshingExample_1", null ],
          [ "Triangulate a Polygon Mesh", "index.html#MeshingExample_2", null ],
          [ "Isotropic Remeshing of a Region on a Polygon Mesh", "index.html#RemeshingExample_1", null ]
        ] ]
      ] ],
      [ "Corefinement and Boolean Operations", "index.html#Coref_section", [
        [ "Definitions", "index.html#coref_def_subsec", null ],
        [ "Corefinement", "index.html#coref_coref_subsec", null ],
        [ "Boolean Operations", "index.html#coref_bolop_subsec", null ],
        [ "Kernel and Validity of the Output", "index.html#coref_valid_subsec", null ],
        [ "Clipping", "index.html#coref_clip", null ],
        [ "Examples", "index.html#coref_ex_subsec", [
          [ "Computing the Union of Two Volumes", "index.html#coref_ex_union_subsec", null ],
          [ "Boolean Operation and Local Remeshing", "index.html#coref_ex_refine_subsec", null ],
          [ "Robustness of Consecutive Operations", "index.html#coref_ex_consq_subsec", null ]
        ] ]
      ] ],
      [ "Hole Filling", "index.html#PMPHoleFilling", [
        [ "API", "index.html#HoleFillingAPI", null ],
        [ "Examples", "index.html#HFExamples", [
          [ "Triangulate a Polyline", "index.html#HFExample_1", null ],
          [ "Hole Filling From the Border of the Hole", "index.html#HFExample_2", null ]
        ] ],
        [ "Performance", "index.html#HFPerformance", null ]
      ] ],
      [ "Predicates", "index.html#PMPPredicates", [
        [ "Intersections Detection", "index.html#PMPDoIntersect", [
          [ "Self Intersections", "index.html#PMPSelIntersections", null ],
          [ "Self Intersections Example", "index.html#SIExample", null ]
        ] ],
        [ "Side of Triangle Mesh", "index.html#PMPInsideTest", [
          [ "Inside Test Example", "index.html#InsideExample", null ]
        ] ],
        [ "Polyhedral Envelope Containment Check", "index.html#PMPEnvelope", [
          [ "Polyhedral Envelope Example", "index.html#PolyhedralEnvelopeExample", null ]
        ] ],
        [ "Shape Predicates", "index.html#PMPShapePredicates", null ],
        [ "Surface Location Functions", "index.html#PMPLocationFunctions", null ]
      ] ],
      [ "Orientation", "index.html#PMPOrientation", [
        [ "Polygon Soups", "index.html#PMPPolygonSoups", null ],
        [ "Polygon Meshes", "index.html#OrientingPolygonMeshes", null ],
        [ "Orientation Examples", "index.html#PolygonSoupExample", null ]
      ] ],
      [ "Combinatorial Repairing", "index.html#PMPRepairing", [
        [ "Polygon Soup Repairing", "index.html#PSRepairing", null ],
        [ "Stitching", "index.html#Stitching", [
          [ "Stitching Example", "index.html#StitchingExample", null ]
        ] ],
        [ "Polygon Mesh Manifoldness", "index.html#PMPManifoldness", [
          [ "Manifoldness Repair Example", "index.html#FixNMVerticeExample", null ]
        ] ],
        [ "Duplicated Vertices in Boundary Cycles", "index.html#PMPDuplicateVertexBoundaryCycle", null ]
      ] ],
      [ "Computing Normals", "index.html#PMPNormalComp", [
        [ "Normals Computation Examples", "index.html#NormalsExample", [
          [ "Normals Computation for a Surface Mesh", "index.html#NormalsExampleSM", null ],
          [ "Normals Computation for a Polyhedron_3", "index.html#NormalsExampleP", null ]
        ] ]
      ] ],
      [ "Slicer", "index.html#PMPSlicer", [
        [ "Slicer Example", "index.html#SlicerExample", null ]
      ] ],
      [ "Connected Components", "index.html#PMPConnectedComponents", [
        [ "Connected Components Example", "index.html#CCExample", null ]
      ] ],
      [ "Hausdorff Distance", "index.html#PMPDistance", [
        [ "Approximate Hausdorff Distance", "index.html#ApproxHD", [
          [ "Approximate Hausdorff Distance Example", "index.html#AHDExample", null ],
          [ "Max Distance Between Point Set and Surface Example", "index.html#PoissonDistanceExample", null ]
        ] ],
        [ "Bounded Hausdorff Distance", "index.html#BoundedHD", [
          [ "Bounded Hausdorff Distance Example", "index.html#BHDExample", null ]
        ] ]
      ] ],
      [ "Feature Detection", "index.html#PMPDetectFeatures", [
        [ "Feature Detection Example", "index.html#DetectFeaturesExample", null ]
      ] ],
      [ "Implementation History", "index.html#PMPHistory", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"group__PMP__repairing__grp.html#ga3722f80ee24b4a245e68e0543d728962"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
